# Deep Search Toolkit

[![PyPI version](https://img.shields.io/pypi/v/deepsearch-toolkit)](https://pypi.org/project/deepsearch-toolkit/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/deepsearch-toolkit)](https://pypi.org/project/deepsearch-toolkit/)
[![License MIT](https://img.shields.io/github/license/ds4sd/deepsearch-toolkit)](https://opensource.org/licenses/MIT)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Docs](https://img.shields.io/badge/website-live-brightgreen)](https://ds4sd.github.io/deepsearch-toolkit/)
[![Downloads](https://static.pepy.tech/badge/deepsearch-toolkit/month)](https://pepy.tech/project/deepsearch-toolkit)


*Interact with the Deep Search platform for new knowledge explorations and discoveries*


The Deep Search Toolkit is a Python SDK and CLI allowing users to interact with the [Deep Search](https://ds4sd.github.io) platform.
The Toolkit provides easy-to-use features for several common document workflows such as conversion, graph creation, and querying, including semantic retrieval and RAG.


## Quick links

- [Deep Search](https://ds4sd.github.io)
- [Deep Search Toolkit](https://ds4sd.github.io/deepsearch-toolkit)
- [Deep Search Examples](https://github.com/ds4sd/deepsearch-examples)


## Install

```shell
pip install deepsearch-toolkit
```

## Getting started

Check out [Getting started](https://ds4sd.github.io/deepsearch-toolkit/#getting-started).


## Get help and support

Please feel free to connect with us using the [discussion section](https://github.com/DS4SD/deepsearch-toolkit/discussions).


## Contributing

Please read [Contributing to Deep Search Toolkit](./CONTRIBUTING.md) for details.


## References

If you use `Deep Search` in your projects, please consider citing the following:

```bib
@software{Deep Search Toolkit,
author = {Deep Search Team},
month = {6},
title = {{Deep Search Toolkit}},
url = {https://github.com/DS4SD/deepsearch-toolkit},
version = {main},
year = {2022}
}
```

## License

The `Deep Search Toolkit` codebase is under MIT license.
For individual model usage, please refer to the model licenses found in the original packages.
